import os

from dotenv import load_dotenv
from lib_clockifybot import add_log
from lib_clockifybot.database import create_database_if_not_exists
from sqlalchemy import Column, Integer, String, Boolean
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker, declarative_base

load_dotenv(os.getenv("CLOCKIFY_ENV"))

VACATION_URL = os.getenv("DATABASE_URL_VACATION")
engine_2 = create_engine(VACATION_URL)
BaseVacation = declarative_base()
SessionLocal_2 = sessionmaker(autocommit=False, autoflush=False, bind=engine_2)


class Vacation(BaseVacation):
    __tablename__ = "vacation"
    id = Column(Integer, primary_key=True, index=True)
    telegram_id = Column(String)
    username = Column(String)
    routine_vacation = Column(String)
    vdate = Column(String)
    from_hour = Column(Integer)
    to_hour = Column(Integer)
    whole_day = Column(Boolean, default=False)
    confirmed_by = Column(String)

    def __repr__(self):
        return f"User('{self.username}') - VacationDate('{self.vdate}' - RoutineVacation('{self.routine_vacation}'))"


def init_vacation_db(bot):
    create_database_if_not_exists(VACATION_URL, bot)
    try:
        BaseVacation.metadata.create_all(engine_2)
    except Exception as e:
        add_log(f"Error creating Vacation table: {e}")
